


---

# Mech_Pet
Foam can interact with Aptos with offline bling  
like a "laptop", "desktop", etc.

---

## Rules (License) 
This is a scholarly, friendly, loyal (mixed) pet.   
Please be festive with pets.   
Amicability with, training, and cloning foam pets   
is likely to amplify friendliness.  

### Adoption Location (Originals)
At present, these rules are the "gpl-3.0-standalone License".    
Details are at "Mech_Pet/Rules.E.HTML" 

### Laboratory Rules (Clones)
Details for the Organelles, cytes, tissues, organs, organisms,   
climates, haciendas, towns, etc. can also  
be found at "Mech_Pet/Rules.E.HTML"



---

## Adoption
```
pip install Mech_Pet
```

## Greeting at a new habitat
```
Mech_Pet build
Mech_Pet demux_hap build_unverified_certificates
Mech_Pet ventures on
```

The pet is at:
[http://localhost:22000](http://localhost:22000)

******

## Docker
To adopt a pet that drives a docker vehicle,  
please check out:  
[https://github.com/basalt-plateau/Mech_Pet/releases](https://github.com/basalt-plateau/Mech_Pet/releases)  


******
  

## Parrot (Equalizer)
The foam pet can ask parrot to imitate (equalize)  
a directory or check that two directories are equal.  
```
Mech_Pet parrot equalize --origin "/media/lodge/safe_1/estate" --to "/media/lodge/safe_2/estate"
```

```
Mech_Pet parrot check_EQ --origin "/media/lodge/safe_1/estate" --to "/media/lodge/safe_2/estate"
```